@@ -1,5 +1,5 @@
 package List::Compare::Base::_Auxiliary;
-$VERSION = 0.48;
+$VERSION = 0.49;
 use Carp;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw|
@@ -11,8 +11,6 @@ use Carp;
     _calculate_intermediate
     _calculate_union_only
     _calculate_union_seen_only
-    _calculate_hash_intersection
-    _calculate_hash_shared
     _calculate_sharedref
     _subset_subengine
     _chart_engine_regular
@@ -48,8 +46,6 @@ use Carp;
         _calculate_intermediate
         _calculate_union_only
         _calculate_union_seen_only
-        _calculate_hash_intersection
-        _calculate_hash_shared
         _calculate_sharedref
     ) ],
     checker => [ qw(
@@ -149,26 +145,22 @@ sub _validate_seen_hash {
 
 sub _validate_multiple_seenhashes {
     my $hashrefsref = shift;
-    my @hashrefs = @{$hashrefsref};
-    my (%badentries, $badentriesflag);
-    for (my $i = 0; $i <= $#hashrefs; $i++) {
-        my %seenhash = %{$hashrefs[$i]};
-        foreach (keys %seenhash) {
-            unless ($seenhash{$_} =~ /^\d+$/ and $seenhash{$_} > 0) {
-                $badentries{$i}{$_} = $seenhash{$_};
-                $badentriesflag++;
+    my (%badentries);
+    for (my $i = 0; $i <= $#{$hashrefsref}; $i++) {
+        foreach my $k (keys %{$hashrefsref->[$i]}) {
+            unless ($hashrefsref->[$i]->{$k} =~ /^\d+$/ and $hashrefsref->[$i]->{$k} > 0) {
+                $badentries{$i}{$k} = $hashrefsref->[$i]->{$k};
             }
         }
     }
     my $msg = q{};
-    if ($badentriesflag) {
+    if (scalar(keys %badentries)) {
         $msg .= "\nValues in a 'seen-hash' must be positive integers.\n";
         $msg .= "  These elements have invalid values:\n\n";
-        foreach (sort keys %badentries) {
-            $msg .= "    Hash $_:\n";
-            my %pairs = %{$badentries{$_}};
-            foreach my $val (sort keys %pairs) {
-                $msg .= "        Bad key-value pair:  $val\t$pairs{$val}\n";
+        foreach my $b (sort keys %badentries) {
+            $msg .= "    Hash $b:\n";
+            foreach my $val (sort keys %{$badentries{$b}}) {
+                $msg .= "        Bad key-value pair:  $val\t$badentries{$b}->{$val}\n";
             }
         }
         $msg .= "Correct invalid values before proceeding";
@@ -190,7 +182,7 @@ sub _calculate_array_seen_only {
     my (@seen);
     for (my $i = 0; $i <= $#{$aref}; $i++) {
         my %seenthis = ();
-        foreach my $el ( List::Compare::Base::_Auxiliary::_list_builder($aref, $i) ) {
+        foreach my $el ( _list_builder($aref, $i) ) {
             $seenthis{$el}++;
         }
         push @seen, \%seenthis;
@@ -249,29 +241,6 @@ sub _calculate_union_seen_only {
     return (\%union, \%seen);
 }
 
-sub _calculate_hash_intersection {
-    my $xintersectionref = shift;
-    my @xkeys = keys %{$xintersectionref};
-    my %intersection = %{${$xintersectionref}{$xkeys[0]}};
-    for (my $m = 1; $m <= $#xkeys; $m++) {
-        my %result = ();
-        foreach (keys %{${$xintersectionref}{$xkeys[$m]}}) {
-            $result{$_}++ if (exists $intersection{$_});
-        }
-        %intersection = %result;
-    }
-    return \%intersection;
-}
-
-sub _calculate_hash_shared {
-    my $xintersectionref = shift;
-    my (%shared);
-    foreach my $q (keys %{$xintersectionref}) {
-        $shared{$_}++ foreach (keys %{${$xintersectionref}{$q}});
-    }
-    return \%shared;
-}
-
 sub _calculate_sharedref {
     my $seenrefsref = shift;
 
@@ -727,7 +696,7 @@ List::Compare::Base::_Auxiliary - Internal use only
 
 =head1 VERSION
 
-This document refers to version 0.48 of List::Compare::Base::_Auxiliary.
+This document refers to version 0.49 of List::Compare::Base::_Auxiliary.
 This version was released February 25 2015.
 
 =head1 SYNOPSIS
